@@ -26,12 +26,15 @@ use album;
 use category;
 use person;
 use place;
+use user;
+
 use conf\conf;
 
 /**
  * This class reads and interpretes CLI arguments
  */
 class arguments {
+
     /** Contains the non-interpreted arguments */
     private $arguments = array();
     /** Contains the interpreted arguments, before lookup */
@@ -88,7 +91,7 @@ class arguments {
         $args["pplace"]=array();
 
         /*
-          Used short arguments: A C D H I N P V X a c d f g h i l n p r t u v w
+          Used short arguments: A C D H I N P U V X a c d f g h i l n p r t u v w
         */
         $size=sizeof($argv);
         for ($i=0; $i<$size; $i++) {
@@ -101,6 +104,25 @@ class arguments {
                 break;
 
 
+            case "--access":
+                $access=explode(",",$argv[++$i]);
+                foreach ($access as $acc) {
+                    $args["_add_access"][]=trim($acc);
+                }
+                break;
+            case "--no-access":
+                $access=explode(",",$argv[++$i]);
+                foreach ($access as $acc) {
+                    $args["_remove_access"][]=trim($acc);
+                }
+                break;
+            case "--admin":
+                $args["_admin"]=true;
+                break;
+            case "--no-admin":
+                $args["_admin"]=false;
+                break;
+
             case "--albums":
             case "--album":
             case "-a":
@@ -152,6 +174,14 @@ class arguments {
                 static::$command="getconfig";
                 $args["_getconfigitem"]=$argv[++$i];
                 break;
+            case "--group":
+            case "-G":
+                $groups=explode(",",$argv[++$i]);
+                foreach ($groups as $group) {
+                    $args["_groups"][]=trim($group);
+                }
+                break;
+
             case "--import":
                 static::$command="import";
                 break;
@@ -185,6 +215,9 @@ class arguments {
             case "--parent":
                 $parent=$argv[++$i];
                 break;
+            case "--password":
+                $args["_password"]=$argv[++$i];
+                break;
 
             case "--thumbs":
             case "-t":
@@ -219,6 +252,16 @@ class arguments {
                 conf::set("import.cli.hash", false);
                 break;
 
+            case "--username":
+            case "--user-name":
+                $args["_username"]=$argv[++$i];
+                break;
+
+            case "--userid":
+            case "--user-id":
+                $args["_userid"]=(int) $argv[++$i];
+                break;
+
 
             case "--update":
             case "-u":
@@ -232,6 +275,28 @@ class arguments {
             case "-N":
                 static::$command="new";
                 break;
+            case "--delete":
+                static::$command="delete";
+                break;
+            case "--user":
+            case "-U":
+                switch ($argv[++$i]) {
+                    case "add":
+                        static::$command="adduser";
+                        break;
+                    case "delete":
+                        static::$command="deleteuser";
+                        break;
+                    case "show":
+                        static::$command="showuser";
+                        break;
+                    case "update":
+                        static::$command="updateuser";
+                        break;
+                    default:
+                        throw new \cliNoUserCommandException(translate("The option --user must be followed by 'add', 'delete', 'show' or 'update' to indicate what you would like to do with a user"));
+                    break;
+                }
 
             case "--useIds":
             case "--useids":
@@ -506,6 +571,32 @@ class arguments {
             case "_xmp":
                 $vars["_xmp"] = true;
                 break;
+            case "_admin":
+                $vars["_admin"] = (bool) $arg;
+
+            case "_add_access":
+            case "_remove_access":
+                /** @todo: implement lookup of various access right */
+                $vars[$type]=$arg;
+                break;
+            case "_group":
+                /** @todo: implement lookup of groups */
+                $vars["_group"]=$arg;
+                break;
+            case "_password":
+                $vars["_password"]=$arg;
+                break;
+            case "_username":
+            case "_userid":
+                if (static::$command=="adduser" && $type == "_username") {
+                    $vars["_username"]=$arg;
+                } else if ($type == "_username") {
+                    $user = user::getByName($arg);
+                    $vars["_userid"]=(int) $user->getId();
+                } else {
+                    $vars["_userid"]=(int) $arg;
+                }
+                break;
             case "_configitem":
             case "_configvalue":
             case "_configdefault":
