@@ -21,15 +21,20 @@
 
 namespace cli;
 
-use file;
-use photo;
 use album;
 use category;
-use place;
+use file;
 use person;
+use photo;
+use place;
 use user;
+
+use auth\validator;
+
 use conf\conf;
+
 use import\cli as cliimport;
+
 use xmp\reader as xmpreader;
 use xmp\decoder as xmpdecoder;
 
@@ -103,6 +108,18 @@ class cli {
         case "dumpconfig":
             $this->doDumpConfig();
             break;
+        case "adduser":
+            $this->doAddUser();
+            break;
+        case "deleteuser":
+            $this->doDeleteUser();
+            break;
+        case "showuser":
+            $this->doShowUser();
+            break;
+        case "updateuser":
+            $this->doUpdateUser();
+            break;
         case "version":
             static::showVersion();
             break;
@@ -419,6 +436,89 @@ class cli {
         }
     }
 
+    /**
+     * Process --user add
+     */
+    private function doAddUser() {
+        $vars=$this->args->getVars();
+        if (!isset($vars["_username"])) {
+            throw new \cliNoUserException(
+                sprintf(translate("No user (%s) specified"), "--username"));
+        }
+        if (!isset($vars["_password"])) {
+            throw new \cliNoPasswordException(
+                translate("No password specified"));
+        }
+
+        $user = new user();
+        $user->set("user_name", $vars["_username"]);
+        $user->set("password", validator::hashPassword($vars["_password"]));
+
+        if (isset($vars["_admin"]) && $vars["_admin"] === true) {
+            $user->set("user_class", 0);
+        } else {
+            $user->set("user_class", 1);
+        }
+
+        $user->insert();
+
+    }
+
+    /**
+     * Process --user delete
+     */
+    private function doDeleteUser() {
+        $vars=$this->args->getVars();
+        if (!isset($vars["_userid"])) {
+            throw new \cliNoUserException(
+                sprintf(translate("No user (%s) specified"), "--username / --userid"));
+        }
+
+    }
+
+    /**
+     * Process --user show
+     */
+    private function doShowUser() {
+        $vars=$this->args->getVars();
+        if (!isset($vars["_userid"])) {
+            throw new \cliNoUserException(
+                sprintf(translate("No user (%s) specified"), "--username / --userid"));
+        }
+        $u = new user($vars["_userid"]);
+        $u->lookup();
+        $da=$u->getDisplayArray();
+        $groups = array_map(
+            function($g) {
+                $g->lookup();
+                return $g->getName(); 
+            }, $u->getGroups()
+        );
+
+        $tpl = new \template\template("cliShowUser", array(
+            "userid"   => $u->get("user_id"),
+            "username"  => $da["username"],
+            "userclass" => $da["class"],
+            "groups"    => $groups,
+            "lastlogin" => $da["last login"],
+            "rights"    => $u->getAccessRightsArray()
+        ));
+
+        echo $tpl . "\n\n";
+    }
+
+    /**
+     * Process --user update
+     */
+    private function doUpdateUser() {
+        $vars=$this->args->getVars();
+        if (!isset($vars["_userid"])) {
+            throw new \cliNoUserException(
+                sprintf(translate("No user (%s) specified"), "--username / --userid"));
+        }
+
+    }
+
     /**
      * Process the --dirpattern setting
      */
