@@ -235,7 +235,7 @@ class confDefault extends conf {
         $pathImages->setDesc("Location of the images on the filesystem. Absolute path, " .
             " thus starting with a /");
         $pathImages->setDefault("/data/images");
-        $pathImages->setRegex("^\/[A-Za-z0-9_.\/]+$");
+        $pathImages->setRegex("^\/[A-Za-z0-9_.\/\-]+$");
         $pathImages->setHint("Alphanumeric characters (A-Z, a-z and 0-9), forward " .
             "slash (/), dot (.), and underscore (_). Must start with a /");
         $pathImages->setRequired();
@@ -344,7 +344,6 @@ class confDefault extends conf {
             "mapping provider");
         $mapsProvider->setLabel("Mapping provider");
         $mapsProvider->addOption("", "Disabled");
-        $mapsProvider->addOption("googlev3", "Google Maps v3");
         $mapsProvider->addOption("mapbox", "Mapbox (OpenStreetMap)");
         $mapsProvider->addOption("osm", "OpenStreetMap");
         $mapsProvider->setDefault("");
@@ -828,6 +827,7 @@ class confDefault extends conf {
             "photo with a textual annotation. Can only be used in combination with the " .
             "\"Mail photos\" feature above.");
         $featureAnnotate->setDefault(false);
+        $featureAnnotate->setDeprecated();
         $feature[]=$featureAnnotate;
 
         $featureRating = new checkbox();
