@@ -206,7 +206,7 @@ class web extends base {
         case "archive":
             $return=static::unpackArchive($file);
             break;
-        case "xml":
+        case "gpx":
             $return=static::XMLimport($file);
             break;
         default:
@@ -419,6 +419,9 @@ class web extends base {
                     $status="done";
                     $xmp = new xmpreader($file);
                     $data=new xmpdecoder($xmp->getXMP());
+                    if (sizeof($data)===0) {
+                        $data = new xmpdecoder($xmp->getXMPfromSidecar());
+                    }
                     $subjects = $data->getSubjects();
                     $rating = $data -> getRating();
                 } else {
@@ -430,7 +433,7 @@ class web extends base {
                 $icon=template::getImage("icons/archive.png");
                 $status="waiting";
                 break;
-            case "xml":
+            case "gpx":
                 $icon=template::getImage("icons/tracks.png");
                 $status="done";
                 break;
@@ -438,6 +441,12 @@ class web extends base {
                 $icon=template::getImage("icons/error.png");
                 $status="ignore";
                 break;
+            case "xmp":
+                // Don't show XMP files
+                // Maybe at some point we can create an icon with the photo showing
+                // an sidecar file was found for this photo
+                continue 2;
+                break;
             }
 
             $xmlfile=$xml->createElement("file");
