@@ -158,7 +158,7 @@ class display extends common {
             "up"            => $this->upURL,
             "next"          => $this->nextURL,
             "full"          => $full=$photo->getFullsizeLink($photo->get("name")),
-            "size"          => template::getHumanReadableBytes($photo->get("size")),
+            "size"          => template::getHumanReadableBytes((int)$photo->get("size")),
             "share"         => $this->getShare(),
             "image"         => $photo->getFullsizeLink($photo->getImageTag(MID_PREFIX)),
             "people"        => isset($people) ? $people : null,
