@@ -338,13 +338,14 @@ class template {
      * @param array array of options
      * @param bool autosubmit form after making a change
      */
-    public static function createPulldown($name, $value, $selectArray, $autosubmit=false) {
+    public static function createPulldown($name, $value, $selectArray, $autosubmit=false, $onchange=null) {
         return new block("select", array(
             "name"  => $name,
             "id"    => preg_replace("/^_+/", "", $name),
             "options" => $selectArray,
             "value" => $value,
-            "autosubmit"    => (bool) $autosubmit
+            "autosubmit"    => (bool) $autosubmit,
+            "onchange" => $onchange
         ));
     }
 
@@ -530,7 +531,7 @@ class template {
      * @param int bytes number of bytes
      * @return string human readable filesize
      */
-    public static function getHumanReadableBytes($bytes) {
+    public static function getHumanReadableBytes(int $bytes) {
         if ($bytes==0) {
             // prevents div by 0
             return "0B";
