@@ -37,7 +37,7 @@ $actionlinks=array(
 );
 
 $tpl=new template("edit", array(
-    "title"         => translate($_action) . " " . translate("place"),
+    "title"         => translate($_action . " " . "place"),
     "actionlinks"   => $actionlinks
 ));
 
