@@ -296,6 +296,31 @@ class cliNotInCWDException extends cliException {}
  */
 class cliIllegalDirpatternException extends cliException {}
 
+/**
+ * Exception for CLI: No user command
+ * This is used in conjuction with the --user option, if no command 
+ * ("add", "delete" "show" or "update") is specified
+ * @author Jeroen Roos
+ * @package zophException
+ */
+class cliNoUserCommandException extends cliException {}
+
+/**
+ * Exception for CLI: No user
+ * This is used in conjuction with the --user option, if no username or user-id is specified
+ * @author Jeroen Roos
+ * @package zophException
+ */
+class cliNoUserException extends cliException {}
+
+/**
+ * Exception for CLI: No password for new user
+ * This is used in conjuction with the --user --new options: no password specified for new user
+ * @author Jeroen Roos
+ * @package zophException
+ */
+class cliNoPasswordException extends cliException {}
+
 /**
  * Exception for CLI: No parent
  * This is used in conjuction with the --new option
@@ -431,6 +456,17 @@ class photoNotAccessibleSecurityException extends securityException {}
  */
 class personNotAccessibleSecurityException extends securityException {}
 
+/**
+ * Insufficient rights Exception
+ * This exception is raised when a user tries to access a function
+ * he is not allowed to use. Since the Zoph UI hides all inaccessible
+ * function, this should only happen if the user is, for example, changing
+ * parameters in the URL.
+ * @author Jeroen Roos
+ * @package zophException
+ */
+class userInsufficientRightsSecurityException extends securityException {}
+
 /**
  * User Exception
  *
