@@ -68,6 +68,7 @@ case "config.php":
     break;
 case "photo.php":
     $scripts[]="js/photoPeople.js";
+    $scripts[]="js/rating.js";
 case "place.php":
     $scripts[]="js/json.js";
     $scripts[]="js/locationLookup.js";
@@ -85,10 +86,7 @@ if (conf::get("interface.autocomplete")) {
 if (conf::get("maps.provider")) {
     $scripts[]="js/leaflet-src.js";
     $scripts[]="js/maps.js";
-    if (conf::get("maps.provider") == "googlev3") {
-        $scripts[]="https://maps.googleapis.com/maps/api/js";
-        $scripts[]="js/Leaflet.GoogleMutant.js";
-    } else if (conf::get("maps.provider") == "mapbox") {
+    if (conf::get("maps.provider") == "mapbox") {
         $javascript[]="var mapbox_api_key = '" . conf::get("maps.mapbox.apikey") . "';";
     }
 
