@@ -22,7 +22,9 @@
 if (!ZOPH) { die("Illegal call"); }
 ?>
 <select name="<?php echo $tpl_name ?>" id="<?php echo $tpl_id ?>"
-    <?php echo ($tpl_autosubmit ? "onChange='form.submit()'" : "") ?> >
+    <?= ($tpl_autosubmit ? "onChange='form.submit()'" : "") ?> 
+    <?= ($tpl_onchange ? "onChange='" . $tpl_onchange . "'" : "") ?>
+    >
     <?php foreach ($tpl_options as $option=>$label): ?>
         <?php if ($tpl_value==$option): ?>
             <?php $selected="selected"; ?>
