@@ -661,7 +661,7 @@ select#rating + input[type="submit"] {
     clear: none;
     top: 4px;
     float: left;
-    width: 40px;
+    width: 120px;
     font-size: medium;
 }
 
@@ -1000,6 +1000,16 @@ div.color {
     width: 60px;
 }
 
+div.cs_example {
+    float: left;
+    width: 15px;
+    height: 15px;
+    margin: 6px 0 -2px 0;
+}
+
+table.colorschemes {
+    width: 100%;
+}
 /* Tables for the permissions */
 
 table.permissions   {
@@ -2021,7 +2031,8 @@ input[type="reset"]:hover {
     color: <?= colorScheme::getColor("selected_tab_font_color") ?>;
 }
 
-input[disabled] {
+input[disabled],
+input[disabled]:hover {
     background: #aaaaaa;
 }
 
@@ -2144,9 +2155,14 @@ table.credits {
     width: 100%;
 }
 
+table.credits {
+    margin: 1em;
+}
+
 table.credits th {
     text-align: right;
-    padding: 2px;
+    padding: 2px 10px 2px 2px;
+
 }
 
 table#users td,
